@@ -6,7 +6,7 @@ import asyncio
 from unittest.mock import patch, Mock
 
 import graphsignal
-from graphsignal.endpoint_trace import EndpointTrace
+from graphsignal.traces import Trace
 
 logger = logging.getLogger('graphsignal')
 
@@ -24,8 +24,8 @@ class GraphsignalAsyncTest(unittest.IsolatedAsyncioTestCase):
     async def asyncTearDown(self):
         graphsignal.shutdown()
 
-    @patch.object(EndpointTrace, '_stop', return_value=None)
-    @patch.object(EndpointTrace, '_start', return_value=None)
+    @patch.object(Trace, '_stop', return_value=None)
+    @patch.object(Trace, '_start', return_value=None)
     async def test_start_trace(self, mocked_start, mocked_stop):
         async def test_func(p):
             return 1 + p
@@ -37,8 +37,8 @@ class GraphsignalAsyncTest(unittest.IsolatedAsyncioTestCase):
         mocked_start.assert_called_once()
         mocked_stop.assert_called_once()
 
-    @patch.object(EndpointTrace, '_stop', return_value=None)
-    @patch.object(EndpointTrace, '_start', return_value=None)
+    @patch.object(Trace, '_stop', return_value=None)
+    @patch.object(Trace, '_start', return_value=None)
     async def test_trace_function(self, mocked_start, mocked_stop):
         @graphsignal.trace_function
         async def test_func(p):
@@ -50,8 +50,8 @@ class GraphsignalAsyncTest(unittest.IsolatedAsyncioTestCase):
         mocked_start.assert_called_once()
         mocked_stop.assert_called_once()
 
-    @patch.object(EndpointTrace, '_stop', return_value=None)
-    @patch.object(EndpointTrace, '_start', return_value=None)
+    @patch.object(Trace, '_stop', return_value=None)
+    @patch.object(Trace, '_start', return_value=None)
     async def test_trace_function_with_args(self, mocked_start, mocked_stop):
         @graphsignal.trace_function(endpoint='ep1', tags=dict(t1='v1'))
         async def test_func(p):
