@@ -11,13 +11,17 @@ class BaseRecorder(ABC):
         pass
 
     @abstractmethod
-    def on_trace_start(self, signal, context, options):
+    def on_trace_start(self, proto, context, options):
         pass
 
     @abstractmethod
-    def on_trace_stop(self, signal, context, options):
+    def on_trace_stop(self, proto, context, options):
         pass
 
     @abstractmethod
-    def on_trace_read(self, signal, context, options):
+    def on_trace_read(self, proto, context, options):
+        pass
+
+    @abstractmethod
+    def on_metric_update(self):
         pass
