@@ -17,12 +17,15 @@ class ONNXRuntimeRecorder(BaseRecorder):
         self._framework.name = 'ONNX Runtime'
         parse_semver(self._framework.version, onnxruntime.__version__)
 
-    def on_trace_start(self, signal, context, options):
+    def on_trace_start(self, proto, context, options):
         pass
 
-    def on_trace_stop(self, signal, context, options):
+    def on_trace_stop(self, proto, context, options):
         pass
 
-    def on_trace_read(self, signal, context, options):
+    def on_trace_read(self, proto, context, options):
         if self._framework:
-            signal.frameworks.append(self._framework)
+            proto.frameworks.append(self._framework)
+
+    def on_metric_update(self):
+        pass
