@@ -12,7 +12,7 @@ import torch
 import graphsignal
 from graphsignal.proto import signals_pb2
 from graphsignal.uploader import Uploader
-from graphsignal.endpoint_trace import DEFAULT_OPTIONS
+from graphsignal.traces import DEFAULT_OPTIONS
 from graphsignal.recorders.pytorch_recorder import PyTorchRecorder
 
 logger = logging.getLogger('graphsignal')
@@ -40,9 +40,9 @@ class PyTorchRecorderTest(unittest.TestCase):
             mem1 = mem1.cuda()
             torch.cuda.synchronize()
 
-        signal = signals_pb2.WorkerSignal()
+        proto = signals_pb2.Trace()
         context = {}
-        recorder.on_trace_start(signal, context, DEFAULT_OPTIONS)
+        recorder.on_trace_start(proto, context, DEFAULT_OPTIONS)
 
         mem2 = torch.rand(10000)
         if torch.cuda.is_available():
@@ -51,20 +51,20 @@ class PyTorchRecorderTest(unittest.TestCase):
         if torch.cuda.is_available():
             torch.cuda.synchronize()
 
-        recorder.on_trace_stop(signal, context, DEFAULT_OPTIONS)
-        recorder.on_trace_read(signal, context, DEFAULT_OPTIONS)
+        recorder.on_trace_stop(proto, context, DEFAULT_OPTIONS)
+        recorder.on_trace_read(proto, context, DEFAULT_OPTIONS)
 
         #pp = pprint.PrettyPrinter()
-        #pp.pprint(MessageToJson(signal))
+        #pp.pprint(MessageToJson(proto))
 
-        self.assertEqual(signal.frameworks[0].name, 'PyTorch')
+        self.assertEqual(proto.frameworks[0].name, 'PyTorch')
 
-        self.assertEqual(signal.frameworks[0].params[0].name, 'torch.cuda.is_available')
-        self.assertEqual(signal.frameworks[0].params[0].value, str(torch.cuda.is_available()))
+        self.assertEqual(proto.frameworks[0].params[0].name, 'torch.cuda.is_available')
+        self.assertEqual(proto.frameworks[0].params[0].value, str(torch.cuda.is_available()))
 
         if torch.cuda.is_available():
-            self.assertEqual(signal.alloc_summary[0].allocator_type, signals_pb2.MemoryAllocation.AllocatorType.PYTORCH_CUDA_ALLOCATOR)
-            self.assertEqual(signal.alloc_summary[0].device_idx, 0)
-            self.assertTrue(signal.alloc_summary[0].allocated_size > 0)
-            self.assertTrue(signal.alloc_summary[0].freed_size > 0)
-            self.assertEqual(signal.alloc_summary[0].num_allocations, 1)
+            self.assertEqual(proto.alloc_summary[0].allocator_type, signals_pb2.MemoryAllocation.AllocatorType.PYTORCH_CUDA_ALLOCATOR)
+            self.assertEqual(proto.alloc_summary[0].device_idx, 0)
+            self.assertTrue(proto.alloc_summary[0].allocated_size > 0)
+            self.assertTrue(proto.alloc_summary[0].freed_size > 0)
+            self.assertEqual(proto.alloc_summary[0].num_allocations, 1)
