@@ -40,12 +40,15 @@ class TensorFlowRecorder(BaseRecorder):
         add_framework_param(self._framework, 'tf.test.is_built_with_gpu_support', tf.test.is_built_with_gpu_support())
         add_framework_param(self._framework, 'tf.test.is_built_with_cuda', tf.test.is_built_with_cuda())
 
-    def on_trace_start(self, signal, context, options):
+    def on_trace_start(self, proto, context, options):
         pass
 
-    def on_trace_stop(self, signal, context, options):
+    def on_trace_stop(self, proto, context, options):
         pass
 
-    def on_trace_read(self, signal, context, options):
+    def on_trace_read(self, proto, context, options):
         if self._framework:
-            signal.frameworks.append(self._framework)
+            proto.frameworks.append(self._framework)
+
+    def on_metric_update(self):
+        pass
