@@ -12,7 +12,7 @@ import tensorflow as tf
 import graphsignal
 from graphsignal.proto import signals_pb2
 from graphsignal.uploader import Uploader
-from graphsignal.endpoint_trace import DEFAULT_OPTIONS
+from graphsignal.traces import DEFAULT_OPTIONS
 from graphsignal.recorders.tensorflow_recorder import TensorFlowRecorder
 
 logger = logging.getLogger('graphsignal')
@@ -42,17 +42,17 @@ class TensorFlowRecorderTest(unittest.TestCase):
 
         recorder = TensorFlowRecorder()
         recorder.setup()
-        signal = signals_pb2.WorkerSignal()
+        proto = signals_pb2.Trace()
         context = {}
-        recorder.on_trace_start(signal, context, DEFAULT_OPTIONS)
-        recorder.on_trace_stop(signal, context, DEFAULT_OPTIONS)
-        recorder.on_trace_read(signal, context, DEFAULT_OPTIONS)
+        recorder.on_trace_start(proto, context, DEFAULT_OPTIONS)
+        recorder.on_trace_stop(proto, context, DEFAULT_OPTIONS)
+        recorder.on_trace_read(proto, context, DEFAULT_OPTIONS)
 
-        self.assertEqual(signal.frameworks[0].name, 'TensorFlow')
+        self.assertEqual(proto.frameworks[0].name, 'TensorFlow')
 
-        self.assertEqual(signal.frameworks[0].params[0].name, 'cluster_size')
-        self.assertEqual(signal.frameworks[0].params[0].value, '3')
-        self.assertEqual(signal.frameworks[0].params[1].name, 'task_index')
-        self.assertEqual(signal.frameworks[0].params[1].value, '1')
-        self.assertEqual(signal.frameworks[0].params[2].name, 'tf.test.is_built_with_gpu_support')
-        self.assertEqual(signal.frameworks[0].params[2].value, str(tf.test.is_built_with_gpu_support()))
+        self.assertEqual(proto.frameworks[0].params[0].name, 'cluster_size')
+        self.assertEqual(proto.frameworks[0].params[0].value, '3')
+        self.assertEqual(proto.frameworks[0].params[1].name, 'task_index')
+        self.assertEqual(proto.frameworks[0].params[1].value, '1')
+        self.assertEqual(proto.frameworks[0].params[2].name, 'tf.test.is_built_with_gpu_support')
+        self.assertEqual(proto.frameworks[0].params[2].value, str(tf.test.is_built_with_gpu_support()))
