@@ -12,7 +12,7 @@ import xgboost as xgb
 import graphsignal
 from graphsignal.proto import signals_pb2
 from graphsignal.uploader import Uploader
-from graphsignal.endpoint_trace import DEFAULT_OPTIONS
+from graphsignal.traces import DEFAULT_OPTIONS
 from graphsignal.recorders.xgboost_recorder import XGBoostRecorder
 
 logger = logging.getLogger('graphsignal')
@@ -34,12 +34,12 @@ class XGBoostRecorderTest(unittest.TestCase):
     def test_record(self):
         recorder = XGBoostRecorder()
         recorder.setup()
-        signal = signals_pb2.WorkerSignal()
+        proto = signals_pb2.Trace()
         context = {}
-        recorder.on_trace_start(signal, context, DEFAULT_OPTIONS)
-        recorder.on_trace_stop(signal, context, DEFAULT_OPTIONS)
-        recorder.on_trace_read(signal, context, DEFAULT_OPTIONS)
+        recorder.on_trace_start(proto, context, DEFAULT_OPTIONS)
+        recorder.on_trace_stop(proto, context, DEFAULT_OPTIONS)
+        recorder.on_trace_read(proto, context, DEFAULT_OPTIONS)
 
-        self.assertEqual(signal.frameworks[0].name, 'XGBoost')
+        self.assertEqual(proto.frameworks[0].name, 'XGBoost')
 
-        self.assertTrue(len(signal.frameworks[0].params) > 0)
+        self.assertTrue(len(proto.frameworks[0].params) > 0)
