@@ -4,6 +4,7 @@ set -e
 
 source venv/bin/activate
 python -m unittest graphsignal/*_test.py
+python -m unittest graphsignal/detectors/*_test.py
 python -m unittest graphsignal/recorders/instrumentation_test.py
 python -m unittest graphsignal/recorders/process_recorder_test.py
 python -m unittest graphsignal/recorders/cprofile_recorder_test.py
@@ -23,5 +24,4 @@ python -m unittest graphsignal/data/builtin_types_test.py
 python -m unittest graphsignal/data/numpy_ndarray_test.py
 python -m unittest graphsignal/data/tf_tensor_test.py
 python -m unittest graphsignal/data/torch_tensor_test.py
-python -m unittest graphsignal/data/missing_value_detector_test.py
 deactivate
